==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/operationalinsights/kotlin/inputs/GetLinkedServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.operationalinsights.kotlin.inputs

import com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property linkedServiceName Name of the linked service.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetLinkedServicePlainArgs(
    public val linkedServiceName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs =
        com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs.builder()
            .linkedServiceName(linkedServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLinkedServicePlainArgs].
 */
@PulumiTagMarker
public class GetLinkedServicePlainArgsBuilder internal constructor() {
    private var linkedServiceName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Name of the linked service.
     */
    @JvmName("ofbdwatgrabagekn")
    public suspend fun linkedServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.linkedServiceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("jebyclooucoktvpb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("uqhlvpwgjohimthh")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetLinkedServicePlainArgs = GetLinkedServicePlainArgs(
        linkedServiceName = linkedServiceName ?: throw PulumiNullFieldException("linkedServiceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/operationalinsights/kotlin/inputs/GetLinkedServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.operationalinsights.kotlin.inputs

import com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property linkedServiceName Name of the linked service.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetLinkedServicePlainArgs(
    public val linkedServiceName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs =
        com.pulumi.azurenative.operationalinsights.inputs.GetLinkedServicePlainArgs.builder()
            .linkedServiceName(linkedServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLinkedServicePlainArgs].
 */
@PulumiTagMarker
public class GetLinkedServicePlainArgsBuilder internal constructor() {
    private var linkedServiceName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Name of the linked service.
     */
    @JvmName("cdqcuguayxjuwafb")
    public suspend fun linkedServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.linkedServiceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gyrdbxxjhlciyjwv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("blotrfxtdseswosm")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetLinkedServicePlainArgs = GetLinkedServicePlainArgs(
        linkedServiceName = linkedServiceName ?: throw PulumiNullFieldException("linkedServiceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
